import { Table, TableBody, Typography } from '@mui/material'
import {
  TableContainer,
  TableHead,
  TableHeadCell,
  TableRow,
  TableCell,
} from 'components/table'
import Page from 'components/page'
import { UserRoleLine } from 'components/roleLine'
import UserConsentLine from 'components/consentLine'
import { useUserContext } from 'contexts'
import { FetchedRole, Role, Consent, FetchedConsent } from 'interfaces'
import { useEffect, useState } from 'react'
import { useTranslation } from 'react-i18next'
import { Navigate } from 'react-router-dom'
import { parseRole, parseConsent } from 'utils'

const GuestPage = () => {
  const { user } = useUserContext()

  const [t] = useTranslation('common')
  const [roles, setRoles] = useState<Role[]>([])
  const [consents, setConsents] = useState<Consent[]>([])
  useEffect(() => {
    setRoles(user.roles.map((role: FetchedRole) => parseRole(role)))
    setConsents(user.consents.map((cons: FetchedConsent) => parseConsent(cons)))
  }, [])
  return (
    <Page>
      <Typography variant="h2">{t('guestInfo.registeredInfo')}</Typography>
      <Typography
        variant="body1"
        sx={{ paddingBottom: '1rem', paddingTop: '1rem' }}
      >
        {t('guestInfo.registeredInfoExplanation')}
      </Typography>

      <Typography variant="h2">{t('guestInfo.contactInfo')}</Typography>
      <TableContainer>
        <Table sx={{ minWidth: 650 }} aria-label="simple table">
          <TableHead sx={{ backgroundColor: 'none' }}>
            <TableRow>
              <TableHeadCell align="left">
                {t('guestInfo.contactInfo')}
              </TableHeadCell>
              <TableHeadCell />
            </TableRow>
          </TableHead>
          <TableBody>
            <TableRow>
              <TableCell align="left">{t('input.fullName')}</TableCell>
              <TableCell align="left">{`${user.first_name} ${user.last_name}`}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.email')}</TableCell>
              <TableCell align="left">{user.email}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('feideId')}</TableCell>
              <TableCell align="left">{user.feide_id}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.nationalIdNumber')}</TableCell>
              <TableCell align="left">{user.fnr}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.passportNumber')}</TableCell>
              <TableCell align="left">{user.passport}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.mobilePhone')}</TableCell>
              <TableCell align="left">{user.mobile_phone}</TableCell>
            </TableRow>
          </TableBody>
        </Table>
      </TableContainer>
      <Typography variant="h2">{t('guestInfo.roleInfoHead')}</Typography>
      <TableContainer>
        <Table sx={{ minWidth: 650 }} aria-label="simple table">
          <TableHead sx={{ backgroundColor: 'none' }}>
            <TableRow>
              <TableHeadCell align="left">{t('common:role')}</TableHeadCell>
              <TableHeadCell align="left">{t('common:period')}</TableHeadCell>
              <TableHeadCell align="left">{t('common:ou')}</TableHeadCell>
            </TableRow>
          </TableHead>
          <TableBody>
            {roles.map((role) => (
              <UserRoleLine key={role.id} role={role} />
            ))}
          </TableBody>
        </Table>
      </TableContainer>
      <Typography variant="h2">{t('guestInfo.consentInfoHead')}</Typography>
      <TableContainer>
        <Table sx={{ minWidth: 650 }} aria-label="simple table">
          <TableHead sx={{ backgroundColor: 'none' }}>
            <TableRow>
              <TableHeadCell align="left">
                {t('guestInfo.consentName')}
              </TableHeadCell>
              <TableHeadCell align="left">
                {t('guestInfo.choiceDate')}
              </TableHeadCell>
              <TableHeadCell align="left">{t('common:choice')}</TableHeadCell>
            </TableRow>
          </TableHead>
          <TableBody>
            {consents.map((cons) => (
              <UserConsentLine key={cons.id} consent={cons} />
            ))}
          </TableBody>
        </Table>
      </TableContainer>
    </Page>
  )
}

const AnonPage = () => {
  const [t] = useTranslation('common')
  return (
    <Page>
      <Typography variant="h2">{t('anonpage.top')}</Typography>
      <Typography variant="body1">{t('anonpage.body')}</Typography>
    </Page>
  )
}

function LandingPage() {
  const { user } = useUserContext()

  if (user.sponsor_id) {
    return <Navigate to="/sponsor" />
  }
  if (user.person_id) {
    if (!user.registration_completed_date) {
      return <Navigate to="/guestregister" />
    }
    return <GuestPage />
  }
  return <AnonPage />
}

export default LandingPage
